@@ -164,7 +164,7 @@ setup_rt_runtime (runtime_spec_schema_config_linux_resources *resources,
   if (UNLIKELY (ret < 0))
     return ret;
 
-  dirfd = open (cgroup_path, O_DIRECTORY | O_CLOEXEC);
+  dirfd = open (cgroup_path, O_DIRECTORY | O_PATH | O_CLOEXEC);
   if (UNLIKELY (dirfd < 0))
     return crun_make_error (err, errno, "open `%s`", cgroup_path);
 
@@ -226,7 +226,7 @@ setup_missing_cpu_options_for_systemd (runtime_spec_schema_config_linux_resource
       if (UNLIKELY (ret < 0))
         return ret;
 
-      dirfd = open (cgroup_path, O_DIRECTORY | O_CLOEXEC);
+      dirfd = open (cgroup_path, O_DIRECTORY | O_PATH | O_CLOEXEC);
       if (UNLIKELY (dirfd < 0))
         return crun_make_error (err, errno, "open `%s`", cgroup_path);
 
@@ -266,7 +266,7 @@ setup_cpuset_for_systemd_v1 (runtime_spec_schema_config_linux_resources *resourc
       if (UNLIKELY (ret < 0))
         return ret;
 
-      dirfd_cpuset = open (path_to_cpuset, O_DIRECTORY | O_RDONLY | O_CLOEXEC);
+      dirfd_cpuset = open (path_to_cpuset, O_DIRECTORY | O_PATH | O_CLOEXEC);
       if (UNLIKELY (dirfd_cpuset < 0))
         return crun_make_error (err, errno, "open `%s`", path_to_cpuset);
 
@@ -1065,6 +1065,13 @@ enter_systemd_cgroup_scope (runtime_spec_schema_config_linux_resources *resource
         }
     }
 
+  sd_err = sd_bus_message_append (m, "(sv)", "DefaultDependencies", "b", 0);
+  if (UNLIKELY (sd_err < 0))
+    {
+      ret = crun_make_error (err, -sd_err, "sd-bus message append DefaultDependencies");
+      goto exit;
+    }
+
   if (annotations)
     {
       size_t prefix_len = sizeof (SYSTEMD_PROPERTY_PREFIX) - 1;
@@ -1105,13 +1112,6 @@ enter_systemd_cgroup_scope (runtime_spec_schema_config_linux_resources *resource
       goto exit;
     }
 
-  sd_err = sd_bus_message_append (m, "(sv)", "DefaultDependencies", "b", 0);
-  if (UNLIKELY (sd_err < 0))
-    {
-      ret = crun_make_error (err, -sd_err, "sd-bus message append DefaultDependencies");
-      goto exit;
-    }
-
   for (i = 0; boolean_opts[i]; i++)
     {
       sd_err = sd_bus_message_append (m, "(sv)", boolean_opts[i], "b", 1);
