@@ -821,7 +821,7 @@ lsm_attr_path (const char *lsm, const char *fname, libcrun_error_t *err)
   cleanup_close int lsm_dirfd = -1;
   char *attr_path = NULL;
 
-  attr_dirfd = open ("/proc/thread-self/attr", O_DIRECTORY | O_RDONLY | O_CLOEXEC);
+  attr_dirfd = open ("/proc/thread-self/attr", O_DIRECTORY | O_PATH | O_CLOEXEC);
   if (UNLIKELY (attr_dirfd < 0))
     {
       crun_make_error (err, errno, "open `/proc/thread-self/attr`");
@@ -831,7 +831,7 @@ lsm_attr_path (const char *lsm, const char *fname, libcrun_error_t *err)
   // Check for newer scoped interface in /proc/thread-self/attr/<lsm>
   if (lsm != NULL)
     {
-      lsm_dirfd = openat (attr_dirfd, lsm, O_DIRECTORY | O_RDONLY | O_CLOEXEC);
+      lsm_dirfd = openat (attr_dirfd, lsm, O_DIRECTORY | O_PATH | O_CLOEXEC);
 
       if (UNLIKELY (lsm_dirfd < 0 && errno != ENOENT))
         {
@@ -1055,6 +1055,8 @@ open_unix_domain_client_socket (const char *path, int dgram, libcrun_error_t *er
   cleanup_close int destfd = -1;
   cleanup_close int fd = -1;
 
+  libcrun_debug ("Opening UNIX domain socket: %s", path);
+
   fd = socket (AF_UNIX, dgram ? SOCK_DGRAM : SOCK_STREAM, 0);
   if (UNLIKELY (fd < 0))
     return crun_make_error (err, errno, "error creating UNIX socket");
@@ -1488,7 +1490,7 @@ getsubidrange (uid_t id, int is_uid, uint32_t *from, uint32_t *len)
           return -1;
         }
 
-      if (ret < 0 && errno != ERANGE)
+      if (ret != ERANGE)
         return ret;
 
       buf_size *= 2;
@@ -1671,8 +1673,13 @@ run_process_with_stdin_timeout_envp (char *path, char **args, const char *cwd, i
   ret = TEMP_FAILURE_RETRY (write (pipe_w, stdin, stdin_len));
   if (UNLIKELY (ret < 0))
     {
-      ret = crun_make_error (err, errno, "writing to pipe");
-      goto restore_sig_mask_and_exit;
+      /* Ignore EPIPE as the container process could have already
+         been terminated.  */
+      if (errno != EPIPE)
+        {
+          ret = crun_make_error (err, errno, "writing to pipe");
+          goto restore_sig_mask_and_exit;
+        }
     }
 
   close_and_reset (&pipe_w);
@@ -2507,3 +2514,17 @@ get_overflow_gid (void)
     }
   return gid;
 }
+
+void
+consume_trailing_slashes (char *path)
+{
+  if (! path || path[0] == '\0')
+    return;
+
+  char *last = path + strlen (path);
+
+  while (last > path && *(last - 1) == '/')
+    last--;
+
+  *last = '\0';
+}
